/*  osdchatd - on-screen display messaging daemon
 *  Copyright (c) 2003 by Mike Smelov  <mike-at-argoncorp-dot-com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  See LICENSE for details.
 *
 */

 /* common.h */

#ifndef __COMMON_H__
#define __COMMON_H__

#include <errno.h>
#include <stdio.h>
#include <stdarg.h>
#include <stdlib.h>
#include <string.h>
#include <syslog.h>
#include <time.h>
//#include <unistd.h>

#define BUFSIZE		512	/* default buffer size */
#define SERV_PORT	7447	/* default service port */
#define NIL		'\0'	/* NULL character */

/* global vars */
int 	debug;			/* set debug mode on */
char 	*progname;		/* program's name */

/* client/server messages */
typedef enum {
	MSG_CONNOK = 0,		/* connection to OSD on X is OK */
	MSG_NODISP,		/* connection ok, but server doesn't have OSD initialized */
	MSG_SERVFULL,		/* maximum number of clients has been reached */
	MSG_CLIBLOCK,		/* client blocked for exceeding warning level */
	MSG_RECEIVED,		/* server received client's message */
	MSG_HOSTDIED,		/* host is terminating */
} msg_t;

/* output debugging levels */
enum {	LVL_DEBUG = 0,		/* print to stdout */
	LVL_INFO,		/* print to stdout, debug need not be set */
	LVL_ERROR,		/* print to stderr */
	LVL_FATERR,		/* print to stderr, then exit */
	LVL_SYSLOG,		/* report to syslog, output to stdout if debug is set */
	LVL_FATAL,		/* report to syslog, output to stdout if debug is set, then exit */
};

/* server's client info */
struct client {
	int 	id;		/* numerical id for client */
	int 	fd;		/* file descriptor for communicating with client */
	int	ip;		/* client's IP */
	char 	*prompt;	/* client's prompt */
	time_t 	tm_lastmsg;	/* time last message was received */
	int 	warning;	/* current warning level */
};

/* function prototypes */
void 	set_limits(int *, int, int);
void 	set_prog_name(char *);
void 	printDBG(int, const char *format, ...);
ssize_t complete_io(ssize_t (*func)(), int, void *, size_t);
void *	xmalloc(size_t);

#endif
